/*
* Copyright (c) 2002 - 2007 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
* which accompanies this distribution, and is available
* at the URL "http://www.eclipse.org/legal/epl-v10.html".
*
* Initial Contributors:
* Nokia Corporation - initial contribution.
*
* Contributors:
*
* Description: playlistenginetest implementation for STIF Test Framework TestScripter.
*
*/



// INCLUDE FILES
#include <Stiftestinterface.h>
#include "playlistenginetest.h"
#include <SettingServerClient.h>



// ============================ MEMBER FUNCTIONS ===============================

// -----------------------------------------------------------------------------
// Cplaylistenginetest::Cplaylistenginetest
// C++ default constructor can NOT contain any code, that
// might leave.
// -----------------------------------------------------------------------------
//
Cplaylistenginetest::Cplaylistenginetest( 
    CTestModuleIf& aTestModuleIf ):
        CScriptBase( aTestModuleIf )
    {
    }

// -----------------------------------------------------------------------------
// Cplaylistenginetest::ConstructL
// Symbian 2nd phase constructor can leave.
// -----------------------------------------------------------------------------
//
void Cplaylistenginetest::ConstructL()
    {
    //Read logger settings to check whether test case name is to be
    //appended to log file name.
    RSettingServer settingServer;
    TInt ret = settingServer.Connect();
    if(ret != KErrNone)
        {
        User::Leave(ret);
        }
    // Struct to StifLogger settigs.
    TLoggerSettings loggerSettings; 
    // Parse StifLogger defaults from STIF initialization file.
    ret = settingServer.GetLoggerSettings(loggerSettings);
    if(ret != KErrNone)
        {
        User::Leave(ret);
        } 
    // Close Setting server session
    settingServer.Close();

    TFileName logFileName;
    
    if(loggerSettings.iAddTestCaseTitle)
        {
        TName title;
        TestModuleIf().GetTestCaseTitleL(title);
        logFileName.Format(KplaylistenginetestLogFileWithTitle, &title);
        }
    else
        {
        logFileName.Copy(KplaylistenginetestLogFile);
        }

    iLog = CStifLogger::NewL( KplaylistenginetestLogPath, 
                          logFileName,
                          CStifLogger::ETxt,
                          CStifLogger::EFile,
                          EFalse );
    
    SendTestClassVersion();
    }

// -----------------------------------------------------------------------------
// Cplaylistenginetest::NewL
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
Cplaylistenginetest* Cplaylistenginetest::NewL( 
    CTestModuleIf& aTestModuleIf )
    {
    Cplaylistenginetest* self = new (ELeave) Cplaylistenginetest( aTestModuleIf );

    CleanupStack::PushL( self );
    self->ConstructL();
    CleanupStack::Pop();

    return self;

    }

// Destructor
Cplaylistenginetest::~Cplaylistenginetest()
    { 

    // Delete resources allocated from test methods
    Delete();

    // Delete logger
    delete iLog; 

    }

//-----------------------------------------------------------------------------
// Cplaylistenginetest::SendTestClassVersion
// Method used to send version of test class
//-----------------------------------------------------------------------------
//
void Cplaylistenginetest::SendTestClassVersion()
	{
	TVersion moduleVersion;
	moduleVersion.iMajor = TEST_CLASS_VERSION_MAJOR;
	moduleVersion.iMinor = TEST_CLASS_VERSION_MINOR;
	moduleVersion.iBuild = TEST_CLASS_VERSION_BUILD;
	
	TFileName moduleName;
	moduleName = _L("playlistenginetest.dll");

	TBool newVersionOfMethod = ETrue;
	TestModuleIf().SendTestModuleVersion(moduleVersion, moduleName, newVersionOfMethod);
	}

// ========================== OTHER EXPORTED FUNCTIONS =========================

void Cplaylistenginetest::HandlePlaylistL(CMPXMedia* /*aPlaylist*/,
    	                                     const TInt aError,
    	                                     const TBool /*aCompleted*/) 
	{
	 iLog->Log(_L("Cplaylistenginetest::HandlePlaylistL returned: %d"),aError);  
	}
    	
 void Cplaylistenginetest::HandlePlaylistL(const TDesC& /*aPlaylistUri*/,
    	                                     const TInt aError) 
	 {
	 iLog->Log(_L("Cplaylistenginetest::HandlePlaylistL returned: %d"),aError);  
	 }
    	
 void Cplaylistenginetest::HandlePluginHandlerEvent(TPluginHandlerEvents /*aEvent*/, const TUid& /*aPluginUid*/,
        TBool /*aLoaded*/, TInt /*aData*/)
	 {
	 iLog->Log(_L("Cplaylistenginetest::HandlePluginHandlerEvent begin:"));  
	 }
// -----------------------------------------------------------------------------
// LibEntryL is a polymorphic Dll entry point.
// Returns: CScriptBase: New CScriptBase derived object
// -----------------------------------------------------------------------------
//
EXPORT_C CScriptBase* LibEntryL( 
    CTestModuleIf& aTestModuleIf ) // Backpointer to STIF Test Framework
    {

    return ( CScriptBase* ) Cplaylistenginetest::NewL( aTestModuleIf );

    }


//  End of File
